From: "Anthony G. Basile" <blueness@gentoo.org>
To: gentoo-commits@lists.gentoo.org
Subject: [gentoo-commits] proj/releng:master commit in: tools-uclibc/desktop/portage/env/, tools-uclibc/desktop/, ...
Date: Sat, 9 May 2015 01:29:27 +0000 (UTC) [thread overview]
Message-ID: <1431134951.d0af5edf0001c37cf7241125d4394ebc322cdf62.blueness@gentoo> (raw)
commit: d0af5edf0001c37cf7241125d4394ebc322cdf62
Author: Anthony G. Basile <blueness <AT> gentoo <DOT> org>
AuthorDate: Wed May 6 11:50:28 2015 +0000
Commit: Anthony G. Basile <blueness <AT> gentoo <DOT> org>
CommitDate: Sat May 9 01:29:11 2015 +0000
URL: https://gitweb.gentoo.org/proj/releng.git/commit/?id=d0af5edf
tools-uclibc/desktop: correct PAX_MARKINGS, add screen and bind-tools.
tools-uclibc/desktop/portage/env/bind-tools.conf | 1 +
tools-uclibc/desktop/portage/make.conf.1 | 1 +
tools-uclibc/desktop/portage/make.conf.2 | 1 +
tools-uclibc/desktop/portage/make.conf.3 | 1 +
tools-uclibc/desktop/portage/package.env | 1 +
tools-uclibc/desktop/run.sh | 15 ++++++++++++---
tools-uclibc/desktop/world.1 | 2 ++
tools-uclibc/desktop/world.2 | 2 ++
8 files changed, 21 insertions(+), 3 deletions(-)
diff --git a/tools-uclibc/desktop/portage/env/bind-tools.conf b/tools-uclibc/desktop/portage/env/bind-tools.conf
new file mode 100644
index 0000000..50fcbfb
--- /dev/null
+++ b/tools-uclibc/desktop/portage/env/bind-tools.conf
@@ -0,0 +1 @@
+LDFLAGS="-liconv"
diff --git a/tools-uclibc/desktop/portage/make.conf.1 b/tools-uclibc/desktop/portage/make.conf.1
index 0edd2e0..9058d76 100644
--- a/tools-uclibc/desktop/portage/make.conf.1
+++ b/tools-uclibc/desktop/portage/make.conf.1
@@ -2,6 +2,7 @@ CFLAGS="-O2 -fstack-check -pipe"
CXXFLAGS="${CFLAGS}"
CHOST="x86_64-gentoo-linux-uclibc"
MAKEOPTS="-j17"
+PAX_MARKINGS="XT"
USE_BASE="bindist mmx mmxext smp sse sse2 ssse3 static-libs -savedconfig"
USE_GCC="graphite objc objc++ objc-gc gtk gtk3 X"
diff --git a/tools-uclibc/desktop/portage/make.conf.2 b/tools-uclibc/desktop/portage/make.conf.2
index de495be..7d55750 100644
--- a/tools-uclibc/desktop/portage/make.conf.2
+++ b/tools-uclibc/desktop/portage/make.conf.2
@@ -2,6 +2,7 @@ CFLAGS="-fstack-check -O2 -pipe"
CXXFLAGS="${CFLAGS}"
CHOST="x86_64-gentoo-linux-uclibc"
MAKEOPTS="-j17"
+PAX_MARKINGS="XT"
USE_BASE="bindist mmx mmxext smp sse sse2 ssse3 static-libs -savedconfig"
USE_GCC="graphite objc objc++ objc-gc gtk gtk3 qt4 X"
diff --git a/tools-uclibc/desktop/portage/make.conf.3 b/tools-uclibc/desktop/portage/make.conf.3
index 4d5dc2b..eca601c 100644
--- a/tools-uclibc/desktop/portage/make.conf.3
+++ b/tools-uclibc/desktop/portage/make.conf.3
@@ -2,6 +2,7 @@ CFLAGS="-fstack-check -O2 -pipe"
CXXFLAGS="${CFLAGS}"
CHOST="x86_64-gentoo-linux-uclibc"
MAKEOPTS="-j17"
+PAX_MARKINGS="XT"
USE_BASE="bindist mmx mmxext smp sse sse2 ssse3 static-libs -savedconfig"
USE_GCC="graphite objc objc++ objc-gc gtk gtk3 qt4 X"
diff --git a/tools-uclibc/desktop/portage/package.env b/tools-uclibc/desktop/portage/package.env
index fecaba8..4fdd279 100644
--- a/tools-uclibc/desktop/portage/package.env
+++ b/tools-uclibc/desktop/portage/package.env
@@ -12,6 +12,7 @@ media-video/ffmpeg ffmpeg.conf
media-video/libav libav.conf
media-video/mplayer2 mplayer2.conf
media-video/xanim xanim.conf
+net-dns/bind-tools bind-tools.conf
net-mail/dovecot dovecot.conf
net-print/cups-filters cups-filters.conf
sys-apps/coreutils coreutils.conf
diff --git a/tools-uclibc/desktop/world.1 b/tools-uclibc/desktop/world.1
index 96ecc42..8631b70 100644
--- a/tools-uclibc/desktop/world.1
+++ b/tools-uclibc/desktop/world.1
@@ -4,6 +4,7 @@ app-arch/file-roller
app-editors/gedit
app-editors/nano
app-editors/vim
+app-misc/screen
app-office/abiword
app-portage/gentoolkit
app-portage/layman
@@ -27,6 +28,7 @@ media-video/smplayer
media-video/totem
net-analyzer/tcpdump
net-dns/avahi
+net-dns/bind-tools
net-fs/samba
net-ftp/lftp
net-irc/hexchat
diff --git a/tools-uclibc/desktop/world.2 b/tools-uclibc/desktop/world.2
index 97076c4..8232e97 100644
--- a/tools-uclibc/desktop/world.2
+++ b/tools-uclibc/desktop/world.2
@@ -4,6 +4,7 @@ app-arch/file-roller
app-editors/gedit
app-editors/nano
app-editors/vim
+app-misc/screen
app-office/abiword
app-office/gnumeric
app-portage/gentoolkit
@@ -28,6 +29,7 @@ media-video/smplayer
media-video/totem
net-analyzer/tcpdump
net-dns/avahi
+net-dns/bind-tools
net-fs/samba
net-ftp/lftp
net-irc/hexchat
next reply other threads:[~2015-05-09 1:29 UTC|newest]
Thread overview: 3+ messages / expand[flat|nested] mbox.gz Atom feed top
2015-05-09 1:29 Anthony G. Basile [this message]
-- strict thread matches above, loose matches on Subject: below --
2014-09-27 7:52 [gentoo-commits] proj/releng:master commit in: tools-uclibc/desktop/portage/env/, tools-uclibc/desktop/, Anthony G. Basile
2014-01-24 18:09 Anthony G. Basile
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=1431134951.d0af5edf0001c37cf7241125d4394ebc322cdf62.blueness@gentoo \
--to=blueness@gentoo.org \
--cc=gentoo-commits@lists.gentoo.org \
--cc=gentoo-dev@lists.gentoo.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
diff --git a/tools-uclibc/desktop/run.sh b/tools-uclibc/desktop/run.sh
index 0bf6986..d365508 100755
--- a/tools-uclibc/desktop/run.sh
+++ b/tools-uclibc/desktop/run.sh
@@ -135,6 +135,11 @@ setup_usergroups() {
setup_confs() {
local IMAGE="http://dev.gentoo.org/~blueness/lilblue/gentoo1600x1200.jpg"
+ # Clean up /etc/portage.
+ sed -i '/^GENTOO_MIRRORS/d' "${ROOTFS}"/etc/portage/make.conf
+ sed -i 's/^MAKEOPTS/#MAKEOPTS/' "${ROOTFS}"/etc/portage/make.conf
+
+ # Change the display greeter to slim and configure.
sed -i 's/^\(DISPLAYMANAGER="\)xdm/\1slim/' "${ROOTFS}"/etc/conf.d/xdm
sed -i 's/^\(login.*\)/# \1/' "${ROOTFS}"/etc/slim.conf
sed -i '/# login_cmd.*Xsession/ a\login_cmd exec /bin/bash -login ~/.xinitrc' "${ROOTFS}"/etc/slim.conf
@@ -144,11 +149,15 @@ setup_confs() {
wget -O "${ROOTFS}"/usr/share/slim/themes/default/background.jpg "${IMAGE}"
#wget -O "${ROOTFS}"/usr/share/pixmaps/backgrounds/gnome/background-default.jpg "${IMAGE}"
- sed -i '/^GENTOO_MIRRORS/d' "${ROOTFS}"/etc/portage/make.conf
- sed -i 's/^MAKEOPTS/#MAKEOPTS/' "${ROOTFS}"/etc/portage/make.conf
+ # Change the hostname to 'lilblue'.
+ sed -i 's/localhost/lilblue/' "${ROOTFS}"/etc/conf.d/hostname
- # In kernels 3.9 and above, we must disallow-other-stacks because of SO_REUSEPORT
+ # In kernels 3.9 and above, we must disallow-other-stacks because of SO_REUSEPORT.
sed -i 's/^#\(disallow-other-stacks=\)no/\1yes/g' "${ROOTFS}"/etc/avahi/avahi-daemon.conf
+
+ # Since we're using an ubuntu-based config, get rid of the evdev spam in dmesg.
+ # https://bugs.launchpad.net/ubuntu/+source/module-init-tools/+bug/240553
+ echo "blacklist evbug" >> "${ROOTFS}"/etc/modprobe.d/blacklist.conf
}
cleanup_dirs() {